==> estateplat-common-1.1.0-20160813.090919-146-sources.jar: cn/gtmap/estateplat/model/exchange/transition/QzJsydsyq.java <==
package cn.gtmap.estateplat.model.exchange.transition;

import javax.persistence.Id;
import javax.persistence.Table;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import java.io.Serializable;
import java.util.Date;

/**
 * Created with IntelliJ IDEA.
 * 建设用地使用权
 * User: lj
 * Date: 15-11-19
 * Time: 下午2:16
 * To change this template use File | Settings | File Templates.
 */
@Table(name = "qz_jsydsyq")
@XmlAccessorType(XmlAccessType.FIELD)
public class QzJsydsyq implements Serializable {
    @Id
    //权利编号
    @XmlElement(name = "qlbh")
    private String qlbh;
    //不动产单元编号
    @XmlElement(name = "bdcdybh")
    private String bdcdybh;
    //业务号
    @XmlElement(name = "ywh")
    private String ywh;
    //地籍号
    @XmlElement(name = "djh")
    private String djh;
    //权利类型
    @XmlElement(name = "qllx")
    private String qllx;
    //使用权面积
    @XmlElement(name = "syqmj")
    private Double syqmj;
    //使用权起始时间
    @XmlElement(name = "syqqssj")
    private Date syqqssj;
    //使用权结束时间
    @XmlElement(name = "syqjssj")
    private Date syqjssj;
    //取得价格
    @XmlElement(name = "qdjg")
    private Double qdjg;
    //备注
    @XmlElement(name = "bz")
    private String bz;

    //原业务号
    private String yywh;

    //涉及相关证书、证明进行转移、变更时，填写对应证书、证明的不动产登记的上次产权证号
    private String ycqzh;

    public String getYywh() {
        return yywh;
    }

    public void setYywh(String yywh) {
        this.yywh = yywh;
    }

    public String getQlbh() {
        return qlbh;
    }

    public void setQlbh(String qlbh) {
        this.qlbh = qlbh;
    }

    public String getBdcdybh() {
        return bdcdybh;
    }

    public void setBdcdybh(String bdcdybh) {
        this.bdcdybh = bdcdybh;
    }

    public String getYwh() {
        return ywh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }

    public String getDjh() {
        return djh;
    }

    public void setDjh(String djh) {
        this.djh = djh;
    }

    public String getQllx() {
        return qllx;
    }

    public void setQllx(String qllx) {
        this.qllx = qllx;
    }

    public Double getSyqmj() {
        return syqmj;
    }

    public void setSyqmj(Double syqmj) {
        this.syqmj = syqmj;
    }

    public Date getSyqqssj() {
        return syqqssj;
    }

    public void setSyqqssj(Date syqqssj) {
        this.syqqssj = syqqssj;
    }

    public Date getSyqjssj() {
        return syqjssj;
    }

    public void setSyqjssj(Date syqjssj) {
        this.syqjssj = syqjssj;
    }

    public Double getQdjg() {
        return qdjg;
    }

    public void setQdjg(Double qdjg) {
        this.qdjg = qdjg;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getYcqzh() {
        return ycqzh;
    }

    public void setYcqzh(String ycqzh) {
        this.ycqzh = ycqzh;
    }
}

==> estateplat-common-1.2.3-20190403.072501-234-sources.jar: cn/gtmap/estateplat/model/exchange/transition/QzJsydsyq.java <==
package cn.gtmap.estateplat.model.exchange.transition;

import javax.persistence.Id;
import javax.persistence.Table;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import java.io.Serializable;
import java.util.Date;

/**
 * Created with IntelliJ IDEA.
 * 建设用地使用权
 * User: lj
 * Date: 15-11-19
 * Time: 下午2:16
 * To change this template use File | Settings | File Templates.
 */
@Table(name = "qz_jsydsyq")
@XmlAccessorType(XmlAccessType.FIELD)
public class QzJsydsyq implements Serializable {
    @Id
    //权利编号
    @XmlElement(name = "qlbh")
    private String qlbh;
    //不动产单元编号
    @XmlElement(name = "bdcdybh")
    private String bdcdybh;
    //业务号
    @XmlElement(name = "ywh")
    private String ywh;
    //地籍号
    @XmlElement(name = "djh")
    private String djh;
    //权利类型
    @XmlElement(name = "qllx")
    private String qllx;
    //使用权面积
    @XmlElement(name = "syqmj")
    private Double syqmj;
    //使用权起始时间
    @XmlElement(name = "syqqssj")
    private Date syqqssj;
    //使用权结束时间
    @XmlElement(name = "syqjssj")
    private Date syqjssj;
    //取得价格
    @XmlElement(name = "qdjg")
    private Double qdjg;
    //备注
    @XmlElement(name = "bz")
    private String bz;

    //原业务号
    private String yywh;

    //涉及相关证书、证明进行转移、变更时，填写对应证书、证明的不动产登记的上次产权证号
    private String ycqzh;

    //登簿人
    @XmlElement(name = "dbr")
    private String dbr;

    public String getDbr() {
        return dbr;
    }

    public void setDbr(String dbr) {
        this.dbr = dbr;
    }

    public String getYywh() {
        return yywh;
    }

    public void setYywh(String yywh) {
        this.yywh = yywh;
    }

    public String getQlbh() {
        return qlbh;
    }

    public void setQlbh(String qlbh) {
        this.qlbh = qlbh;
    }

    public String getBdcdybh() {
        return bdcdybh;
    }

    public void setBdcdybh(String bdcdybh) {
        this.bdcdybh = bdcdybh;
    }

    public String getYwh() {
        return ywh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }

    public String getDjh() {
        return djh;
    }

    public void setDjh(String djh) {
        this.djh = djh;
    }

    public String getQllx() {
        return qllx;
    }

    public void setQllx(String qllx) {
        this.qllx = qllx;
    }

    public Double getSyqmj() {
        return syqmj;
    }

    public void setSyqmj(Double syqmj) {
        this.syqmj = syqmj;
    }

    public Date getSyqqssj() {
        return syqqssj;
    }

    public void setSyqqssj(Date syqqssj) {
        this.syqqssj = syqqssj;
    }

    public Date getSyqjssj() {
        return syqjssj;
    }

    public void setSyqjssj(Date syqjssj) {
        this.syqjssj = syqjssj;
    }

    public Double getQdjg() {
        return qdjg;
    }

    public void setQdjg(Double qdjg) {
        this.qdjg = qdjg;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getYcqzh() {
        return ycqzh;
    }

    public void setYcqzh(String ycqzh) {
        this.ycqzh = ycqzh;
    }
}
